var _ogre_deflate_8h =
[
    [ "Ogre::DeflateStream", "class_ogre_1_1_deflate_stream.html", "class_ogre_1_1_deflate_stream" ],
    [ "Ogre::StaticCache&lt; cacheSize &gt;", "class_ogre_1_1_static_cache.html", "class_ogre_1_1_static_cache" ],
    [ "z_stream", "_ogre_deflate_8h.html#a8697d4541486ef84a6eef760663668ac", null ]
];